API Details
=============

.. toctree::

    anyconfig.api
    anyconfig.backends
    anyconfig.backend
    anyconfig.mdicts
    anyconfig.schema

:mod:`anyconfig`
-----------------

.. automodule:: anyconfig

